<?php




function ix_lookup_postcode($postcode, $housenr) {
    global $wpdb;
    
    $webserviceResponse = null;
    
    
    $sql = $wpdb->prepare("select * from {$wpdb->prefix}postcode_cache where postcode = %s and housenr = %s ", $postcode, $housenr);
    $rows = $wpdb->get_results($sql);
    if (count($rows)) {
        $webserviceResponse = $rows[0]->response;
    } else {
        $url = 'https://api.pdok.nl/bzk/locatieserver/search/v3_1/free?fq='.urlencode('postcode:'.$postcode).'&fq='.urlencode('huisnummer~'.$housenr . '*');
        $response = file_get_contents( $url );
        
        $solrResponse = json_decode($response);
        if ($solrResponse != false && isset($solrResponse->response)) {
            $wpdb->query( $wpdb->prepare("insert into {$wpdb->prefix}postcode_cache (postcode, housenr, response, created) values (%s, %s, %s, now())", $postcode, $housenr, $response) );
            
            $webserviceResponse = $response;
        }
    }
    
    // no response?
    if ($webserviceResponse == null)
        return null;
        
    $r = json_decode( $webserviceResponse );
    
    // hmz..
    if ($r == false) {
        return null;
    }
    
    // nothing found?
    if (count($r->response->docs) == 0)
        return null;
        
        
    $doc = $r->response->docs[0];
    
    $result = array(
        'province' => $doc->provincienaam,
        'city' => $doc->woonplaatsnaam,
        'street' => $doc->straatnaam
    );
    
    return $result;
}


function ix_ajax_lookup_postcode() {
    header('Content-type: application/json');
    
    // fetch input
    $postcode = trim(strtoupper($_REQUEST['postcode']));
    $housenr = trim($_REQUEST['housenr']);
    
    $postcode = preg_replace('/[^\\dA-Z]/', '', $postcode);
    
    // validate input
    $errors = array();
    if (preg_match('/^\\d{4}[A-Z][A-Z]$/', $postcode) == false)
        $errors['postcode'] = 'invalid';
        
    $matches = array();
    $housenr = preg_match('/^(\\d+).*$/', $housenr, $matches);
    if (count($matches) == 0) {
        $errors['housenr'] = 'required';
    } else {
        $housenr = $matches[1];
    }
    
    // errors? => response with error
    if (count($errors)) {
        $result = array();
        $result['error'] = true;
        $result['errors'] = $errors;
        print json_encode($result, JSON_PRETTY_PRINT);
        wp_die();
    }
    
    
    
    $r = ix_lookup_postcode($postcode, $housenr);
    
    $result = array();
    if ($r != null) {
        $result = $r;
        $result['found'] = true;
    } else {
        $result['found'] = false;
    }
    
    print json_encode($result);
    wp_die();
}
add_action('wp_ajax_lookup_postcode', 'ix_ajax_lookup_postcode');
add_action('wp_ajax_nopriv_lookup_postcode', 'ix_ajax_lookup_postcode');

